OC.L10N.register(
    "settings",
    {
    "Private" : "Privat",
    "Only visible to people matched via phone number integration through Talk on mobile" : "Endast synlig för personer matchade via telefonnummer integration via Talk i mobilen",
    "Local" : "Lokal",
    "Only visible to people on this instance and guests" : "Endast synlig för personer på denna instansen och gäster",
    "Federated" : "Federerad",
    "Only synchronize to trusted servers" : "Synkronisera endast med betrodda servrar",
    "Published" : "Publicerad",
    "Synchronize to trusted servers and the global and public address book" : "Synkronisera med betrodda servrar och den globala och offentliga adressboken",
    "Verify" : "Verifiera",
    "Verifying …" : "Verifierar ...",
    "Unable to change password" : "Kunde inte ändra lösenord",
    "Very weak password" : "Väldigt svagt lösenord",
    "Weak password" : "Svagt lösenord",
    "So-so password" : "Okej lösenord",
    "Good password" : "Bra lösenord",
    "Strong password" : "Starkt lösenord",
    "Groups" : "Grupper",
    "Group list is empty" : "Grupplistan är tom",
    "Unable to retrieve the group list" : "Kan inte hämta grupplistan",
    "{actor} added you to group {group}" : "{actor} adderade dig till gruppen {group}",
    "You added {user} to group {group}" : "Du adderade {user} till gruppen {group}",
    "{actor} added {user} to group {group}" : "{actor} adderade {user} till gruppen {group}",
    "An administrator added you to group {group}" : "En administratör adderade dig till gruppen {group}",
    "An administrator added {user} to group {group}" : "En administratör adderade {user} till gruppen {group}",
    "{actor} removed you from group {group}" : "{actor} tog bort dig från gruppen {group}",
    "You removed {user} from group {group}" : "Du tog bort {user} från gruppen {group}",
    "{actor} removed {user} from group {group}" : "{actor} tog bort {user} från gruppen {group}",
    "An administrator removed you from group {group}" : "En administratör tog bort dig från gruppen {group}",
    "An administrator removed {user} from group {group}" : "En administratör tog bort {user} från gruppen {group}",
    "Your <strong>group memberships</strong> were modified" : "Dina <strong>gruppmedlemskaper</strong> har ändrats",
    "{actor} changed your password" : "{actor} ändrade ditt lösenord",
    "You changed your password" : "Du ändrade ditt lösenord",
    "Your password was reset by an administrator" : "Ditt lösenord återställdes av en administratör",
    "Your password was reset" : "Ditt lösenord återställdes",
    "{actor} changed your email address" : "{actor} ändrade din e-postadress",
    "You changed your email address" : "Du ändrade din e-postadress",
    "Your email address was changed by an administrator" : "Din e-postadress ändrades av en administratör",
    "You created an app password for a session named \"{token}\"" : "Du skapade ett applösenord för en session med namnet \"{token}\"",
    "An administrator created an app password for a session named \"{token}\"" : "En administratör skapade ett applösenord för en session med namnet \"{token}\"",
    "You deleted app password \"{token}\"" : "Du tog bort applösenordet \"{token}\"",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Du ändrade namn på applösenord \"{token}\" till \"{newToken}\"",
    "You granted filesystem access to app password \"{token}\"" : "Du tilldelade filsystem-åtkomst till applösenord \"{token}\"",
    "You revoked filesystem access from app password \"{token}\"" : "Du återkallade filsystem-åtkomst från applösenord \"{token}\"",
    "Security" : "Säkerhet",
    "You successfully logged in using two-factor authentication (%1$s)" : "Du loggade in med tvåfaktorautentisering (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Ett inloggningsförsök med tvåfaktorautentisering misslyckades (%1$s)",
    "Remote wipe was started on %1$s" : "Fjärrensning startades på %1$s",
    "Remote wipe has finished on %1$s" : "Fjärrensning slutfördes på %1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Ditt <strong>lösenord</strong> eller <strong>e-postadress</strong> har ändrats",
    "Settings" : "Inställningar",
    "Could not remove app." : "Kunde inte ta bort app.",
    "Could not update app." : "Kunde inte uppdatera app.",
    "Wrong password" : "Fel lösenord",
    "Unable to change personal password" : "Kunde inte byta personligt lösenord",
    "Saved" : "Sparad",
    "No Login supplied" : "Ingen inloggning angiven",
    "Unable to change password. Password too long." : "Kunde inte byta lösenord. Lösenord för långt.",
    "Authentication error" : "Fel vid autentisering",
    "Please provide an admin recovery password; otherwise, all account data will be lost." : "Ange ett lösenord för administratörsåterställning; annars kommer all kontodata att gå förlorad.",
    "Wrong admin recovery password. Please check the password and try again." : "Felaktigt återställningslösenord för administratör. Kontrollera lösenordet och prova igen.",
    "Backend does not support password change, but the encryption of the account key was updated." : "Backend stödjer inte att lösenord ändras, men krypteringen på kontots nyckel uppdaterades.",
    "Administrator documentation" : "Administratörsdokumentation",
    "User documentation" : "Användardokumentation",
    "Nextcloud help overview" : "Nextcloud hjälpöversikt",
    "Invalid SMTP password." : "Ogiltigt SMTP-lösenord.",
    "Email setting test" : "E-postinställningar test",
    "Well done, %s!" : "Bra gjort, %s!",
    "If you received this email, the email configuration seems to be correct." : "Om du får detta e-postmeddelande så har du ställt in e-postinställningarna rätt.",
    "Email could not be sent. Check your mail server log" : "E-post kunde inte skickas. Titta i din e-postserverlogg",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Ett problem uppstod när e-post försökte skickas. Kontrollera dina inställningar. (Fel: %s)",
    "You need to set your account email before being able to send test emails. Go to %s for that." : "Du måste ställa in epostadressen på kontot innan du kan skicka testmail. Gå till %s för att göra det.",
    "Recently active" : "Nyligen aktiv",
    "Disabled accounts" : "Inaktiverade konton",
    "Invalid account" : "Felaktigt konto",
    "Invalid mail address" : "Ogiltig e-postadress",
    "Settings saved" : "Inställningar sparade",
    "Unable to change full name" : "Kunde inte ändra namn",
    "Unable to change email address" : "Kunde inte ändra e-postadress",
    "Unable to set invalid phone number" : "Kunde inte sätta ogiltigt telefonnummer",
    "Unable to set invalid website" : "Kunde inte sätta ogiltig webbplats",
    "Some account data was invalid" : "Någon kontoinformation var ogiltig",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "För att verifiera dit Twitter-konto, posta följande tweet på Twitter (Var säker att det postas utan radbrytningar):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "För att verifiera din webbplats, lagra följande innehåll i din webbrot på '.well-known/CloudIdVerificationCode.txt' (Vänligen säkerställ att hela texten ryms på en rad):",
    "%1$s changed your password on %2$s." : "%1$s ändrade ditt lösenord på %2$s",
    "Your password on %s was changed." : "Ditt lösenord på %s har ändrats.",
    "Your password on %s was reset by an administrator." : "Ditt lösenord på %s har blivit återställt av en administratör.",
    "Your password on %s was reset." : "Ditt lösenord på %s återställdes.",
    "Password for %1$s changed on %2$s" : "Lösenord för %1$s ändrades %2$s",
    "Password changed for %s" : "Lösenord ändrat för %s",
    "If you did not request this, please contact an administrator." : "Om du inte har begärt detta, vänligen kontakta en administratör.",
    "Your email address on %s was changed." : "Din e-postadress på %s har ändrats.",
    "Your email address on %s was changed by an administrator." : "Din e-postadress på %s har ändrats av en administratör.",
    "Email address for %1$s changed on %2$s" : "E-postadressen för %1$s ändrades %2$s",
    "Email address changed for %s" : "E-postadress ändrad för %s",
    "The new email address is %s" : "Nya e-postadressen är %s",
    "Your %s account was created" : "Ditt %s konto skapades",
    "Welcome aboard" : "Välkommen ombord",
    "Welcome aboard %s" : "Välkommen ombord %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Välkommen till ditt %s konto, du kan lägga till, skydda och dela din data.",
    "Your Login is: %s" : "Din inloggning är: %s",
    "Set your password" : "Ställ in ditt lösenord",
    "Go to %s" : "Gå till %s",
    "Install Client" : "Installera Klient",
    "Apps" : "Appar",
    "Personal" : "Privat",
    "Administration" : "Administration",
    "Users" : "Användare",
    "Additional settings" : "Övriga inställningar",
    "Artificial Intelligence" : "Artificiell intelligens",
    "Administration privileges" : "Administreringsprivilegier",
    "Groupware" : "Grupprogram",
    "Overview" : "Översikt",
    "Basic settings" : "Generella inställningar",
    "Sharing" : "Dela",
    "Availability" : "Din tillgänglighet",
    "Calendar" : "Kalender",
    "Personal info" : "Personlig information",
    "Mobile & desktop" : "Mobil & skrivbord",
    "Email server" : "E-postserver",
    "Mail Providers" : "E-postleverantörer",
    "Mail provider enables sending emails directly through the user's personal email account. At present, this functionality is limited to calendar invitations. It requires Nextcloud Mail 4.1 and an email account in Nextcloud Mail that matches the user's email address in Nextcloud." : "E-postleverantörer gör det möjligt att skicka e-post direkt via användarens personliga e-postkonto. För närvarande är denna funktionalitet begränsad till kalenderinbjudningar. Det kräver Nextcloud Mail 4.1 och ett e-postkonto i Nextcloud Mail som matchar användarens e-postadress i Nextcloud.",
    "Send emails using" : "Skicka e-post med",
    "User's email account" : "Användarens e-postkonto",
    "System email account" : "Systemets mailkonto",
    "Security & setup checks" : "Säkerhet & konfigurationstest",
    "Background jobs" : "Bakgrundsjobb",
    "Unlimited" : "Obegränsat",
    "Verifying" : "Verifiera",
    "Allowed admin IP ranges" : "Tillåten IP-rymd för administratörer",
    "Configuration key \"%1$s\" expects an array (%2$s found). Admin IP range validation will not be applied." : "Konfigurationsnyckel \"%1$s\" förväntar sig en array (%2$s hittades). Validering av IP-intervall för administratörer tillämpas inte.",
    "Configuration key \"%1$s\" contains invalid IP range(s): \"%2$s\"" : "Konfigurationsnyckel \"%1$s\" innehåller ogiltiga IP-intervall: \"%2$s\"",
    "App directories owner" : "App-katalogens ägare",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:\n%s" : "Vissa appkataloger ägs av en annan användare än den som äger webbservern. Detta kan vara fallet om appar har installerats manuellt. Kontrollera behörigheterna för följande appkataloger:\n%s",
    "App directories have the correct owner \"%s\"" : "App-kataloger har rätt ägare \"%s\"",
    "Brute-force Throttle" : "Brute-force begränsningar",
    "Your remote address could not be determined." : "Din fjärradress kunde inte fastställas.",
    "Your remote address \"%s\" is not brute-force throttled." : "Din adress \"%s\" är inte bruteforce-begränsad.",
    "Code integrity" : "Kodintegritet",
    "Integrity checker has been disabled. Integrity cannot be verified." : "Integritetskontrollen har inaktiverats. Integritet kan inte verifieras.",
    "No altered files" : "Inga ändrade filer",
    "Some files have not passed the integrity check. {link1} {link2}" : "Några filer har inte klarat integritetskontrollen. {link1} {link2}",
    "Cron errors" : "Cron-fel",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:\n%s" : "Det var inte möjligt att utföra cron-jobbet via CLI. Följande tekniska fel har uppstått:\n%s",
    "The last cron job ran without errors." : "Det senaste cron-jobbet kördes utan fel.",
    "Cron last run" : "Cron senaste körning",
    "Last background job execution ran %s. Something seems wrong. {link}." : "Senaste bakgrundsjobbet kördes %s. Något verkar vara fel. {link}.",
    "Last background job execution ran %s." : "Senaste bakgrundsjobbet kördes %s.",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Serverns datakatalog och filer är sannolikt fritt tillgängliga över internet. Nextclouds .htaccess-fil fungerar ej. Det rekommenderas starkt att du konfigurerar webbservern på så vis att datamappen inte är tillgänglig för vem som helst på internet, eller flyttar den utanför webbserverns dokument-rot. ",
    "Database missing columns" : "Databas saknar kolumner",
    "Missing optional column \"%s\" in table \"%s\"." : "Saknar valfri kolumn \"%s\" i tabellen \"%s\".",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Databasen saknar några valfria kolumner. Eftersom att lägga till sådana i stora tabeller kan ta en del tid, har det inte gjorts automatiskt. Genom att köra kommandot \"occ db:add-missing-columns\" läggs de saknade kolumnerna till utan att instansen behöver stoppas. Att lägga till de valfria kolumnerna kan förbättra svarstid eller användbarhet.",
    "Database missing indices" : "Databasen saknar index",
    "Missing indices:" : "Saknade index:",
    "\"%s\" in table \"%s\"" : "\"%s\" i tabell \"%s\"",
    "Database missing primary keys" : "Databasen saknar primärnycklar",
    "Missing primary key on table \"%s\"." : "Saknar primärnyckel på tabellen \"%s\".",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "Databasen saknar några primärnycklar. Eftersom att lägga till sådana i stora tabeller kan ta en del tid, har det inte gjorts automatiskt. Genom att köra kommandot \"occ db:add-missing-primary-keys\" läggs de saknade primärnycklarna till utan att instansen behöver stoppas.",
    "Database pending bigint migrations" : "Databas väntar på bigint-migreringar",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline." : "Vissa kolumner i databasen saknar en konvertering till big int. Eftersom att ändra kolumners typer på stora tabeller kan ta tid ändrades de inte automatiskt. Genom att köra \"occ db:convert-filecache-bigint\" kan dessa väntande ändringar appliceras manuellt. Denna operation måste utföras när instansen är offline.",
    "Debug mode" : "Felsökningsläge",
    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "Den här instansen körs i felsökningsläge. Aktivera detta endast för lokal utveckling och inte i produktionsmiljöer.",
    "Debug mode is disabled." : "Felsökningsläget är inaktiverat",
    "Default phone region" : "Standardregion för telefon",
    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective ISO 3166-1 code of the region to your config file." : "Din installation har ingen standardregion för telefon inställd. Detta krävs för att validera telefonnummer i profilinställningarna utan landskod. För att tillåta nummer utan landskod, lägg till \"default_phone_region\" med respektive ISO 3166-1-kod för regionen i din konfigurationsfil.",
    "Email test" : "E-posttest",
    "Email test was successfully sent" : "E-posttestet har skickats",
    "You have not set or verified your email server configuration, yet. Please head over to the \"Basic settings\" in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "Du har inte ställt in eller verifierat din e-postserverkonfiguration ännu. Gå över till \"Generella inställningar\" för att ställa in dem. Använd sedan knappen \"Skicka e-post\" under formuläret för att verifiera dina inställningar.",
    "The database is used for transactional file locking. To enhance performance, please configure memcache, if available." : "Databasen används till transaktionsbaserad fillåsning. För att förbättra prestandan, konfigurera memcache om det finns tillgängligt.",
    "Your IP address was resolved as %s" : "Din IP-adress identifierades som %s",
    "Internet connectivity" : "Internetanslutning",
    "Internet connectivity is disabled in configuration file." : "Internetanslutning är inaktiverad i konfigurationsfilen.",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Den här servern har ingen fungerande internetanslutning: Flera slutpunkter kunde inte nås. Det betyder att vissa av funktionerna som montering av extern lagring, aviseringar om uppdateringar eller installation av tredjepartsappar inte kommer att fungera. Att komma åt filer på distans och skicka e-postmeddelanden kanske inte heller fungerar. Upprätta en anslutning från denna server till internet för att kunna nyttja alla funktioner.",
    "Old server-side-encryption" : "Gammal serverkryptering",
    "Disabled" : "Inaktiverad",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "Det gamla krypteringsformatet på servern är aktiverat. Vi rekommenderar att du inaktiverar detta.",
    "Logging level" : "Loggnivå",
    "Logging level configured correctly." : "Loggnivå är korrekt konfigurerad.",
    "Maintenance window start" : "Underhållsfönster startar",
    "Server has no maintenance window start time configured. This means resource intensive daily background jobs will also be executed during your main usage time. We recommend to set it to a time of low usage, so users are less impacted by the load caused from these heavy tasks." : "Servern har ingen konfigurerad starttid för underhållsfönster. Detta innebär att resurskrävande dagliga bakgrundsjobb också kommer att köras under din huvudsakliga användningstid. Vi rekommenderar att du ställer in det till en tid med låg användning, så att användarna påverkas mindre av belastningen som orsakas av dessa tunga uppgifter.",
    "Maintenance window to execute heavy background jobs is between {start}:00 UTC and {end}:00 UTC" : "Underhållsfönstret för att utföra tunga bakgrundsjobb är mellan {start}:00 UTC och {end}:00 UTC",
    "Memcache" : "Memcache",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available." : "Inget minnescache har konfigurerats. För att förbättra prestanda, vänligen konfigurera en memcache, om tillgänglig.",
    "Configured" : "Konfigurerad",
    "You are not using MySQL" : "Du använder inte MySQL",
    "MySQL Unicode support" : "MySQL Unicode support",
    "MySQL is used as database and does support 4-byte characters" : "MySQL används som databas och stödjer 4-byte-tecken",
    "Overwrite CLI URL" : "Skriv över CLI-URL",
    "PHP default charset" : "PHP standardteckenuppsättning",
    "PHP set_time_limit" : "PHP set_time_limit",
    "The function is available." : "Funktionen är tillgänglig.",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "PHP-funktionen \"set_time_limit\" är inte tillgänglig. Detta kan leda till att skript stoppas i mitten av utförandet och bryter din installation. Aktivering av denna funktion rekommenderas starkt.",
    "Supported" : "Stöds",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Din PHP har inte FreeType-stöd, vilket resulterar i brott i profilbilder och inställningsgränssnittet.",
    "PHP getenv" : "PHP getenv",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP verkar inte vara korrekt inställd för att fråga efter systemmiljövariabler. Testet med getenv(\"PATH\") ger bara ett tomt svar.",
    "PHP memory limit" : "PHP minnesgräns",
    "PHP modules" : "PHP-moduler",
    "This instance is missing some required PHP modules. It is required to install them: %s." : "Den här instansen saknar några nödvändiga PHP-moduler. Det är nödvändigt att installera dem: %s.",
    "PHP opcache" : "PHP opcache",
    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "PHP OPcache-modulen är inte laddad. För bättre prestanda rekommenderas det att ladda den i din PHP-installation.",
    "Correctly configured" : "Korrekt konfigurerad",
    "PHP version" : "PHP-version",
    "You are currently running PHP %s." : "Du kör för närvarande PHP %s.",
    "PHP \"output_buffering\" option" : "Inställningen för PHP \"output_buffering\"",
    "Push service" : "Push-tjänst",
    "Valid enterprise license" : "Giltigt enterprise-licens",
    "Free push service" : "Gratis push-tjänst",
    "Random generator" : "Slumpgenerator",
    "Secure" : "Säkra",
    "Configuration file access rights" : "Behörighet för konfigurationsfil",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Den skrivskyddade konfigurationen har aktiverats. Detta förhindrar att vissa konfigurationer ställs in via webbgränssnittet. Dessutom måste filen göras skrivbar manuellt för varje uppdatering.",
    "Nextcloud configuration file is writable" : "Nextcloud-konfigurationsfilen är skrivbar",
    "HTTP headers" : "HTTP headers",
    "- The `%1$s` HTTP header is not set to `%2$s`, `%3$s`, `%4$s`, `%5$s` or `%6$s`. This can leak referer information. See the {w3c-recommendation}." : "- HTTP header `%1$s` är inte inställd till `%2$s`, `%3$s`, `%4$s`, `%5$s` eller `%6$s`. Detta kan leda till att din server läcker referer-information. Läs {w3c-recommendation}.",
    "Database version" : "Databasversion",
    "Unknown database platform" : "Okänd databasplattform",
    "Architecture" : "Arkitektur",
    "64-bit" : "64-bit",
    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit!" : "Det verkar som att du kör en 32-bitars PHP-version. Nextcloud behöver 64-bitars för att fungera bra. Vänligen uppgradera ditt OS och PHP till 64-bitars!",
    "Temporary space available" : "Tillfälligt utrymme tillgängligt",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Databasen körs inte med transaktionsisoleringsnivån \"READ COMMITTED\". Det kan orsaka problem när flera aktiviteter körs parallellt.",
    ".well-known URLs" : ".well-known URLs",
    "Font file loading" : "Font fil laddas",
    "Profile information" : "Profilinformation",
    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Profilbild, fullständigt namn, e-post, telefonnummer, adress, webbplats, Twitter, organisation, roll, rubrik, biografi och om din profil är aktiverad",
    "Nextcloud settings" : "Nextcloud-inställningar",
    "Task:" : "Uppgift:",
    "Enable" : "Aktivera",
    "Machine translation" : "Maskinöversättning",
    "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment." : "Maskinöversättning kan implementeras av olika appar. Här kan du definiera prioritet för de maskinöversättningsappar som du har installerade.",
    "Image generation" : "Bildgenerering",
    "Image generation can be implemented by different apps. Here you can set which app should be used." : "Bildgenerering kan implementeras av olika appar. Här kan du ställa in vilken app som ska användas.",
    "None of your currently installed apps provide image generation functionality" : "Ingen av dina för närvarande installerade appar tillhandahåller bildgenereringsfunktioner",
    "Text processing" : "Textbehandling",
    "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task." : "Textbearbetningsuppgifter kan implementeras av olika appar. Här kan du ställa in vilken app som ska användas för vilken uppgift.",
    "Here you can decide which group can access certain sections of the administration settings." : "Här kan du bestämma vilken grupp som har tillgång till vissa delar av administrationsinställningarna.",
    "Unable to modify setting" : "Kunde inte ändra inställning.",
    "None" : "Ingen",
    "Changed disclaimer text" : "Ändrade friskrivningstext",
    "Deleted disclaimer text" : "Raderade friskrivningstext",
    "Could not set disclaimer text" : "Det gick inte att ange friskrivningstext",
    "Allow apps to use the Share API" : "Tillåt applikationer att använda API för delning",
    "Allow resharing" : "Tillåt vidaredelning",
    "Allow sharing with groups" : "Tillåt delning med grupper",
    "Restrict users to only share with users in their groups" : "Begränsa användare till att enbart kunna dela med användare i deras grupper",
    "Ignore the following groups when checking group membership" : "Ignorera följande grupper när du kontrollerar gruppmedlemskap",
    "Allow users to share via link and emails" : "Tillåt användare att dela via länk och e-post",
    "Allow public uploads" : "Tillåt offentlig uppladdning",
    "Always ask for a password" : "Fråga alltid efter lösenord",
    "Enforce password protection" : "Tillämpa lösenordskydd",
    "Exclude groups from password requirements" : "Exkludera grupper från lösenordskrav",
    "Exclude groups from creating link shares" : "Exkludera grupper från att skapa länkdelningar",
    "Limit sharing based on groups" : "Begränsa delning baserat på grupper",
    "Allow sharing for everyone (default)" : "Tillåt delning för alla (standard)",
    "Exclude some groups from sharing" : "Uteslut vissa grupper från att dela",
    "Limit sharing to some groups" : "Begränsa delning till vissa grupper",
    "Groups allowed to share" : "Grupper som får dela",
    "Groups excluded from sharing" : "Grupper exkluderade från delning",
    "Not allowed groups will still be able to receive shares, but not to initiate them." : "Ej tillåtna grupper kommer fortfarande att kunna ta emot delningar, men inte initiera dem.",
    "Set default expiration date for internal shares" : "Ställ in standardutgångsdatum för interna delningar",
    "Enforce expiration date" : "Tillämpa utgångsdatum",
    "Default expiration time of new shares in days" : "Standardutgångstid för nya delningar i dagar",
    "Expire shares after x days" : "Delningar förfaller efter x dagar",
    "Set default expiration date for shares to other servers" : "Ställ in standardutgångsdatum för delningar till andra servrar",
    "Enforce expiration date for remote shares" : "Tillämpa utgångsdatum för fjärrdelningar",
    "Default expiration time of remote shares in days" : "Standardutgångstid för fjärrdelningar i dagar",
    "Expire remote shares after x days" : "Fjärrdelningar förfaller efter x dagar",
    "Set default expiration date for shares via link or mail" : "Ställ in standardutgångsdatum för delningar via länk eller e-post",
    "Default expiration time of shares in days" : "Standardutgångstid för delningar i dagar",
    "Privacy settings for sharing" : "Sekretessinställningar för delning",
    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Om komplettering för \"samma grupp\" och \"telefonnummerintegration\" är aktiverade räcker det med en matchning i en av dem för att visa användaren.",
    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Tillåt autokomplettering när du anger hela namnet eller e-postadressen (ignorera saknad telefonboksmatchning och att vara i samma grupp)",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Visa friskrivningstext på offentliga uppladdningssidan (visas endast när fil-listan är gömd)",
    "Disclaimer text" : "Friskrivningstext",
    "This text will be shown on the public link upload page when the file list is hidden." : "Denna text kommer att visa på den offentliga uppladdnings-sidan när fil-listan är gömd.",
    "Default share permissions" : "Standardrättigheter för delning",
    "Two-Factor Authentication" : "Tvåfaktorsautentisering",
    "Enforce two-factor authentication" : "Påtvinga tvåfaktorsautentisering",
    "Limit to groups" : "Begränsa till grupper",
    "Enforcement of two-factor authentication can be set for certain groups only." : "Påtvingad tvåfaktorsautentisering kan bara aktiveras för vissa grupper.",
    "Two-factor authentication is enforced for all members of the following groups." : "Tvåfaktorsautentisering är påtvingad för alla medlemmar i följande grupper.",
    "Enforced groups" : "Påtvingade grupper",
    "Two-factor authentication is not enforced for members of the following groups." : "Tvåfaktorsautentisering är inte påtvingad för medlemmar i följande grupper.",
    "Excluded groups" : "Exkluderade grupper",
    "Save changes" : "Spara ändringar",
    "Show details for {appName} app" : "Visa detaljer för appen {appName}",
    "Update to {update}" : "Uppdatera till {update}",
    "Remove" : "Ta bort",
    "Featured" : "Utvalda",
    "This app is supported via your current Nextcloud subscription." : "Den här appen stöds via ditt nuvarande Nextcloud-abonnemang.",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Utvalda appar utvecklas av och inom gemenskapen. De erbjuder central funktionalitet och är redo för produktionsanvändning.",
    "Disable all" : "Inaktivera alla",
    "Download and enable all" : "Ladda ner och aktivera alla",
    "All apps are up-to-date." : "Alla appar är uppdaterade.",
    "Icon" : "Ikon",
    "Name" : "Namn",
    "Version" : "Version",
    "Level" : "Nivå",
    "Actions" : "Funktioner",
    "Results from other categories" : "Resultat från andra kategorier",
    "No apps found for your version" : "Inga appar funna för din version",
    "_%n app has an update available_::_%n apps have an update available_" : ["%n app har en uppdatering tillgänglig","%n appar har en uppdatering tillgänglig"],
    "_Update_::_Update all_" : ["Uppdatera","Uppdatera alla"],
    "Failed to load groups" : "Kunde inte läsa in grupper",
    "Failed to create group" : "Det gick inte att skapa gruppen",
    "Creating group…" : "Skapar grupp...",
    "Create group" : "Skapa grupp",
    "Group name" : "Gruppnamn",
    "Please enter a valid group name" : "Ange ett giltigt gruppnamn",
    "Search groups…" : "Sök grupper…",
    "List of groups. This list is not fully populated for performance reasons. The groups will be loaded as you navigate or search through the list." : "Grupplista. Denna lista är inte fullständigt inläst av prestandaskäl. Grupperna kommer att laddas när du navigerar eller söker i listan.",
    "Loading groups…" : "Hämtar grupper...",
    "Nothing to show" : "Inget att visa",
    "Could not load section content from app store." : "Det gick inte att ladda avsnittsinnehåll från app store.",
    "Loading" : "Läser in",
    "Fetching the latest news…" : "Hämtar de senaste nyheterna...",
    "Carousel" : "Karusell",
    "Previous slide" : "Föregående sida",
    "Next slide" : "Nästa sida",
    "Choose slide to display" : "Välj sida att visa",
    "{index} of {total}" : "{index} av {total}",
    "Daemon" : "Demon",
    "Type" : "Typ",
    "Display Name" : "Visningsnamn",
    "Learn more" : "Läs mer",
    "Confirm" : "Bekräfta",
    "Cancel" : "Avbryt",
    "Description" : "Beskrivning",
    "View in store" : "Visa i butik",
    "Visit website" : "Besök webbplats",
    "Usage documentation" : "Användardokumentation",
    "Admin documentation" : "Administratörsdokumentation",
    "Developer documentation" : "Utvecklardokumentation",
    "Details" : "Detaljer",
    "All" : "Alla",
    "Limit app usage to groups" : "Begränsa appanvändning till grupper",
    "No results" : "Inga resultat",
    "Update to {version}" : "Uppdatera till {version}",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Denna app har ingen lägsta Nextcloud-version tilldelad. Detta kommer att innebära ett problem i framtiden.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Denna app har ingen minimum Nextcloud-version tilldelad. Detta kommer att innebära ett problem i framtiden.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Denna applikation kan inte installeras då följande beroenden inte är uppfyllda: %s",
    "Latest updated" : "Senast uppdaterad",
    "Author" : "Upphovsman",
    "Categories" : "Kategorier",
    "Resources" : "Resurser",
    "Documentation" : "Dokumentation",
    "Interact" : "Interagera",
    "Report a bug" : "Rapportera ett problem",
    "Request feature" : "Begär egenskap",
    "Ask questions or discuss" : "Ställ frågor eller diskutera",
    "Rate the app" : "Betygsätt appen",
    "Rate" : "Betygsätt",
    "Changelog" : "Ändringslogg",
    "Google Chrome for Android" : "Google Chrome för Android",
    "{productName} iOS app" : "{productName} iOS app",
    "{productName} Android app" : "{productName} Android app",
    "{productName} Talk for iOS" : "{productName} Talk för iOS",
    "{productName} Talk for Android" : "{productName} Talk för Android",
    "Sync client" : "Synkklient",
    "This session" : "Denna session ",
    "{client} - {version} ({system})" : "{client} - {version} ({system})",
    "{client} - {version}" : "{client} - {version}",
    "Device name" : "Enhetsnamn",
    "Cancel renaming" : "Avbryt namnändring",
    "Save new name" : "Spara nya namnet",
    "Marked for remote wipe" : "Markerad för fjärrensning",
    "Device settings" : "Enhetsinställningar",
    "Allow filesystem access" : "Tillåt åtkomst till filsystemet",
    "Rename" : "Byt namn",
    "Revoke" : "Återkalla",
    "Wipe device" : "Rensa enhet",
    "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "Återkallning kan förhindra att enheten rensas om inte rensningen redan har startat.",
    "Device" : "Enhet",
    "Last activity" : "Senaste aktivitet",
    "Devices & sessions" : "Enheter & sessioner",
    "Web, desktop and mobile clients currently logged in to your account." : "Webb-, skrivbords- och mobila klienter som är inloggade på ditt konto just nu.",
    "Error while creating device token" : "Fel vid skapande av enhetstoken",
    "App name" : "Appnamn",
    "Create new app password" : "Skapa nytt applösenord",
    "App password copied!" : "Applösenordet har kopierats!",
    "Copy app password" : "Kopiera applösenord",
    "Login name copied!" : "Inloggningsnamnet kopierat!",
    "Copy login name" : "Kopiera inloggningsnamn",
    "Could not copy app password. Please copy it manually." : "Det gick inte att kopiera applösenordet. Kopiera det manuellt.",
    "Could not copy login name. Please copy it manually." : "Kunde inte kopiera inloggningsnamnet. Kopiera det manuellt.",
    "New app password" : "Nytt applösenord",
    "Use the credentials below to configure your app or device. For security reasons this password will only be shown once." : "Använd inloggningsuppgifterna nedan för att konfigurera din app eller enhet. Av säkerhetsskäl kommer detta lösenord endast att visas en gång.",
    "Login" : "Logga in",
    "Password" : "Lösenord",
    "Show QR code for mobile apps" : "Visa QR-kod för mobila appar",
    "Use system cron service to call the cron.php file every 5 minutes." : "Använd systemets cron-tjänst för att anropa cron.php var 5: e minut.",
    "The PHP POSIX extension is required. See {linkstart}PHP documentation{linkend} for more details." : "PHP POSIX-tillägget krävs. Se {linkstart}PHP-dokumentationen{linkend} för mer information.",
    "Unable to update background job mode" : "Det gick inte att uppdatera bakgrundsjobbläget",
    "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "För att servern ska fungera korrekt är det viktigt att konfigurera bakgrundsjobb korrekt. Cron är den rekommenderade inställningen. Se dokumentationen för mer information.",
    "Last job execution ran {time}. Something seems wrong." : "Senaste jobbexekveringen kördes {time}. Något verkar vara fel.",
    "Last job ran {relativeTime}." : "Senaste jobbet kördes {relativeTime}.",
    "Background job did not run yet!" : "Bakgrundsjobb har inte kört ännu!",
    "AJAX" : "AJAX",
    "Webcron" : "Webcron",
    "Cron (Recommended)" : "Cron (Rekommenderad)",
    "Unable to update profile default setting" : "Det gick inte att uppdatera profilens standardinställning",
    "Profile" : "Profil",
    "Enable or disable profile by default for new accounts." : "Aktivera eller inaktivera profil som standard för nya konton.",
    "Failed to save setting" : "Kunde inte spara inställning",
    "Unable to update server side encryption config" : "Kunde inte uppdatera serversidans krypteringskonfiguration",
    "Server-side encryption" : "Serverkryptering",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Kryptering från servern möjliggör kryptering av filer som är uppladdade till servern. Detta innebär vissa begränsningar som prestandaförluster, så aktivera bara om det behövs.",
    "Enable server-side encryption" : "Aktivera kryptering på server.",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Ingen krypteringsmodul inläst, aktivera krypteringsmodulen i applikationsmenyn.",
    "Select default encryption module:" : "Välj krypteringsmodul:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "Du måste migrera dina krypteringsnycklar från den gamla krypteringen (ownCloud <= 8.0) till den nya. Aktivera \"Standard krypteringsmodule\" och kör {command}",
    "Enable encryption" : "Aktivera kryptering",
    "Please read carefully before activating server-side encryption:" : "Läs noga innan du aktiverar kryptering på serversidan:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "När kryptering är aktiverat, så kommer alla filer som laddas upp till servern från den tidpunkt och framåt bli krypterad på servern. Det kommer bara vara möjligt att inaktivera kryptering vid ett senare tillfälle om krypteringsmodulen stödjer den funktionen och alla förvillkor (exempelvis använder återställningsnyckel) är mötta.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Enbart kryptering garanterar inte säkerhet i systemet. Se dokumentationen för ytterligare information om hur krypteringsappen fungerar, och de supporterade användarfallen.",
    "Be aware that encryption always increases the file size." : "OBS! Observera att kryptering alltid ökar filstorleken",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Det är alltid en god ide att skapa regelbundna säkerhetskopior av din data, om kryptering används var säker på att även krypteringsnycklarna säkerhetskopieras tillsammans med din data.",
    "This is the final warning: Do you really want to enable encryption?" : "Detta är en slutgiltig varning: Vill du verkligen aktivera kryptering?",
    "Failed to remove group \"{group}\"" : "Det gick inte att ta bort gruppen \"{group}\"",
    "Please confirm the group removal" : "Bekräfta borttagning av gruppen",
    "You are about to remove the group \"{group}\". The accounts will NOT be deleted." : "Du håller på att ta bort gruppen \"{group}\". Kontona kommer INTE att raderas.",
    "Submit" : "Skicka",
    "Rename group" : "Byt namn på grupp",
    "Remove group" : "Ta bort grupp",
    "Current password" : "Nuvarande lösenord",
    "New password" : "Nytt lösenord",
    "Change password" : "Ändra lösenord",
    "Choose your profile picture" : "Välj din profilbild",
    "Please select a valid png or jpg file" : "Välj en giltig png- eller jpg-fil",
    "Error setting profile picture" : "Fel vid inställning av profilbild",
    "Error cropping profile picture" : "Det gick inte att beskära profilbilden",
    "Error saving profile picture" : "Det gick inte att spara profilbilden",
    "Error removing profile picture" : "Det gick inte att ta bort profilbilden",
    "Your profile picture" : "Din profilbild",
    "Upload profile picture" : "Ladda upp profilbild",
    "Choose profile picture from Files" : "Välj profilbild från filer",
    "Remove profile picture" : "Ta bort profilbild",
    "The file must be a PNG or JPG" : "Filen måste vara en PNG eller JPG",
    "Picture provided by original account" : "Bild gjordes tillgänglig av orginalkonto",
    "Set as profile picture" : "Ställ in som profilbild",
    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Observera att det kan ta upp till 24 timmar för din profilbild att uppdateras överallt.",
    "Your biography. Markdown is supported." : "Din biografi. Markdown stöds.",
    "Unable to update date of birth" : "Det gick inte att uppdatera födelsedatum",
    "Enter your date of birth" : "Ange ditt födelsedatum",
    "You are using {s}{usage}{/s}" : "Du använder {s}{usage}{/s}",
    "You are using {s}{usage}{/s} of {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})" : "Du använder {s}{usage}{/s} av {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})",
    "You are a member of the following groups:" : "Du är medlem i följande grupper:",
    "Your full name" : "Ditt fullständiga namn",
    "Email options" : "E-postinställningar",
    "Options for additional email address {index}" : "Alternativ för ytterligare e-postadress {index}",
    "Remove primary email" : "Ta bort primär e-postadress",
    "Delete email" : "Ta bort e-post",
    "This address is not confirmed" : "Denna adress är inte verifierad",
    "Unset as primary email" : "Ta bort som primär e-post",
    "Set as primary email" : "Välj som primär e-post",
    "Additional email address {index}" : "Ytterligare e-postadress {index}",
    "Unable to delete primary email address" : "Kunde inte ta bort primär e-postadress",
    "Unable to update primary email address" : "Kunde inte uppdatera primär e-postadress",
    "Unable to add additional email address" : "Kunde inte lägga till ytterligare e-postadress",
    "Unable to update additional email address" : "Kunde inte uppdatera ytterligare e-postadress",
    "Unable to delete additional email address" : "Kunde inte ta bort ytterligare e-postadress",
    "Primary email for password reset and notifications" : "Primär e-postadress för notifikationer och återställning av lösenord",
    "No email address set" : "Ingen e-postadress angiven",
    "Your handle" : "Ditt kontonamn",
    "Derived from your locale ({weekDayName})" : "Härledd från din plats ({weekDayName})",
    "Unable to update first day of week" : "Kunde inte uppdatera första veckodagen",
    "Day to use as the first day of week" : "Dag att använda som första veckodag",
    "Your headline" : "Din rubrik",
    "Unable to update language" : "Kunde inte uppdatera språk",
    "Languages" : "Språk",
    "Help translate" : "Hjälp till med översättningarna",
    "No language set" : "Inget språk angivet",
    "Unable to update locale" : "Det gick inte att uppdatera språk",
    "Locales" : "Platser",
    "Week starts on {firstDayOfWeek}" : "Veckan börjar med {firstDayOfWeek}",
    "No locale set" : "Inget språk angivet",
    "Your city" : "Din stad",
    "Your organisation" : "Din organisation",
    "Your phone number" : "Ditt telefonnummer",
    "Edit your Profile visibility" : "Ändra synligheten för din profil",
    "Unable to update profile enabled state" : "Kunde inte uppdatera profilaktivering",
    "Enable profile" : "Aktivera profil",
    "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "Den mer restriktiva inställningen av antingen synlighet eller omfattning respekteras på din profil. Till exempel, om synlighet är inställd på \"Visa för alla\" och omfattningen är inställd på \"Privat\", respekteras \"Privat\".",
    "Unable to update visibility of {displayId}" : "Kunde inte uppdatera synlighet för {displayId}",
    "she/her" : "hon/henne",
    "he/him" : "han/honom",
    "they/them" : "de/dem",
    "Your role" : "Din roll",
    "Your X (formerly Twitter) handle" : "Ditt användarnamn på X (tidigare Twitter)",
    "Your website" : "Din webbsida",
    "Invalid value" : "Ogiltigt värde",
    "Unable to update {property}" : "Det gick inte att uppdatera {property}",
    "No {property} set" : "Ingen {property} inställd",
    "Change scope level of {property}, current scope is {scope}" : "Ändra omfattningsnivå för {property}, nuvarande omfattning är {scope}",
    "Unable to update federation scope of the primary {property}" : "Det gick inte att uppdatera federationsomfånget för den primära {property}",
    "Unable to update federation scope of additional {property}" : "Det gick inte att uppdatera federationens omfattning för ytterligare {property}",
    "Add additional email" : "Lägg till ytterligare e-post",
    "Add" : "Lägg till",
    "Create" : "Skapa",
    "Change" : "Ändra",
    "Delete" : "Radera",
    "Reshare" : "Dela vidare",
    "Default language" : "Standardspråk",
    "Common languages" : "Vanliga språk",
    "Other languages" : "Andra språk",
    "Password change is disabled because the master key is disabled" : "Lösenordsbyte är inaktiverat eftersom huvudnyckeln är inaktiverad",
    "No accounts" : "Inga konton",
    "Loading accounts …" : "Laddar konton ...",
    "List of accounts. This list is not fully rendered for performance reasons. The accounts will be rendered as you navigate through the list." : "Lista över konton. Denna lista är inte helt återgiven av prestandaskäl. Konton kommer att renderas när du navigerar genom listan.",
    "Manager" : "Chef",
    "Set line manager" : "Ange linjechef",
    "Account name will be autogenerated" : "Kontonamn kommer att autogenereras",
    "Account name (required)" : "Kontonamn (obligatoriskt)",
    "Failed to search groups" : "Kunde inte söka efter grupper",
    "New account" : "Nytt konto",
    "Display name" : "Visningsnamn",
    "Either password or email is required" : "Antingen lösenord eller e-post krävs",
    "Password (required)" : "Lösenord (obligatoriskt)",
    "Email (required)" : "E-post (obligatoriskt)",
    "Email" : "E-post",
    "Member of the following groups (required)" : "Medlem i följande grupper (obligatoriskt)",
    "Member of the following groups" : "Medlem i följande grupper",
    "Set account groups" : "Ställ in kontogrupper",
    "Admin of the following groups" : "Administratör för följande grupper",
    "Set account as admin for …" : "Ange konto som administratör för ...",
    "Quota" : "Lagringsutrymme",
    "Set account quota" : "Ställ in kvot för konto",
    "Language" : "Språk",
    "Set default language" : "Ställ in standardspråk",
    "Add new account" : "Lägg till nytt konto",
    "_{userCount} account …_::_{userCount} accounts …_" : ["{userCount} konto …","{userCount} konton …"],
    "_{userCount} account_::_{userCount} accounts_" : ["{userCount} konto","{userCount} konton"],
    "Total rows summary" : "Sammanfattning antal rader",
    "Scroll to load more rows" : "Bläddra för att ladda fler rader",
    "Password or insufficient permissions message" : "Lösenord eller meddelande om otillräckliga behörigheter",
    "Avatar" : "Avatar",
    "Account name" : "Kontonamn",
    "Group admin for" : "Gruppadministratör för",
    "Storage location" : "Lagringsplats",
    "Last login" : "Senaste inloggning",
    "Account actions" : "Kontoåtgärder",
    "{size} used" : "{size} använt",
    "Delete account" : "Radera konto",
    "Disconnect all devices and delete local data" : "Koppla bort alla enheter och radera lokalt data",
    "Disable account" : "Inaktivera konto",
    "Enable account" : "Aktivera konto",
    "Resend welcome email" : "Skicka om välkomstmeddelande via e-post",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Om användaren förlorar sin enhet eller lämnar organisationen, kan all Nextcloud-data fjärrensas från alla enheter associerade med {userid}. Fungerar bara om enheterna är anslutna till internet.",
    "Remote wipe of devices" : "Fjärrensning av enheter",
    "Wipe {userid}'s devices" : "Rensa enheter för {userid}",
    "Wiped {userid}'s devices" : "Rensade enheter för {userid}",
    "Failed to load groups with details" : "Kunde inte läsa in grupper med detaljer",
    "Failed to update line manager" : "Kunde inte uppdatera linjechef",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Fullständig radering av konto för {userid} inklusive alla personliga filer, appdata etc.",
    "Account deletion" : "Radering av konto",
    "Delete {userid}'s account" : "Ta bort konto för {userid}",
    "Display name was successfully changed" : "Visningsnamnet har ändrats",
    "Password can't be empty" : "Lösenord får inte vara tomt",
    "Password was successfully changed" : "Lösenordet har ändrats",
    "Email can't be empty" : "E-post får inte vara tomt",
    "Email was successfully changed" : "E-postadressen har ändrats",
    "Welcome mail sent!" : "Välkomstmeddelande skickat via e-post!",
    "Loading account …" : "Laddar konto ...",
    "Change display name" : "Ändra visningsnamn",
    "Set new password" : "Ange nytt lösenord",
    "You do not have permissions to see the details of this account" : "Du har inte behörighet att se detaljerna för detta konto.",
    "Set new email address" : "Ange ny e-postadress",
    "Add account to group" : "Lägg till konto till grupp",
    "Set account as admin for" : "Ange konto som administratör för",
    "Select account quota" : "Välj kvot för konto",
    "Set the language" : "Ställ in språk",
    "Toggle account actions menu" : "Växla menyn med kontoåtgärder",
    "Done" : "Färdig",
    "Edit" : "Redigera",
    "Account management settings" : "Inställningar kontohantering",
    "Visibility" : "Synlighet",
    "Show language" : "Visa språk",
    "Show storage path" : "Visa lagringsväg",
    "Show last login" : "Visa senaste inloggning",
    "Sorting" : "Sortering",
    "The system config enforces sorting the groups by name. This also disables showing the member count." : "Systemkonfigurationen tvingar sortering av grupper efter namn. Detta inaktiverar också visning av medlemsantal.",
    "Group list sorting" : "Sortering av grupplistor",
    "By member count" : "Efter medlemsantal",
    "By name" : "Efter namn",
    "Send email" : "Skicka e-post",
    "Send welcome email to new accounts" : "Skicka välkomstmail till nya konton",
    "Defaults" : "Standardvärden",
    "Default quota" : "Standard kvot",
    "Select default quota" : "Välj standard kvot",
    "Server error while trying to complete WebAuthn device registration" : "Serverfel när du försökte slutföra registreringen av en WebAuthn-enhet",
    "Passwordless authentication requires a secure connection." : "Lösenordsfri autentisering kräver en säker anslutning.",
    "Add WebAuthn device" : "Lägg till WebAuthn-enhet",
    "Please authorize your WebAuthn device." : "Godkänn din WebAuthn-enhet.",
    "Adding your device …" : "Lägger till din enhet ....",
    "Unnamed device" : "Namnlös enhet",
    "Passwordless Authentication" : "Lösenordsfri autentisering",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Ställ in ditt konto för lösenordsfri autentisering som följer FIDO2-standarden.",
    "No devices configured." : "Inga enheter konfigurerade.",
    "The following devices are configured for your account:" : "Följande enheter är konfigurerade för ditt konto:",
    "Your browser does not support WebAuthn." : "Din webbläsare stödjer inte WebAuthn.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Som administratör kan du fininställa delningsbeteendet. Vänligen se dokumentationen för mer information.",
    "You need to enable the File sharing App." : "Du måste aktivera fildelnings-appen.",
    "App Store" : "App Store",
    "Loading app list" : "Laddar applista",
    "Loading categories" : "Laddar kategorier",
    "Developer documentation ↗" : "Utvecklardokumentation ↗",
    "Version {version}, {license}-licensed" : "Version {version}, {license}-licensierad",
    "All accounts" : "Alla konton",
    "Admins" : "Administratörer",
    "Account group: {group}" : "Kontogrupp: {group}",
    "Account management" : "Kontohantering",
    "Sending…" : "Skickar...",
    "Email sent" : "E-post skickad",
    "Location" : "Plats",
    "Profile picture" : "Profilbild",
    "About" : "Om",
    "Date of birth" : "Födelsedatum",
    "Full name" : "Namn",
    "Additional email" : "Ytterligare e-postadress",
    "Fediverse (e.g. Mastodon)" : "Fediverse (t.ex. Mastodon)",
    "Headline" : "Rubrik",
    "Organisation" : "Organisation",
    "Phone number" : "Telefonnummer",
    "Pronouns" : "Pronomen",
    "Role" : "Roll",
    "X (formerly Twitter)" : "X (tidigare Twitter)",
    "Website" : "Webbplats",
    "Profile visibility" : "Profilsynlighet",
    "Locale" : "Plats",
    "First day of week" : "Första dagen i veckan",
    "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Inte tillgänglig då denna inställning krävs för essentiell funktionalitet såsom fildelning och kalenderinbjudningar",
    "Not available as federation has been disabled for your account, contact your system administration if you have any questions" : "Ej tillgängligt eftersom federation har inaktiverats för ditt konto, kontakta din systemadministratör om du har några frågor",
    "Discover" : "Upptäck",
    "Your apps" : "Dina appar",
    "Active apps" : "Aktiva appar",
    "Disabled apps" : "Inaktiverade appar",
    "Updates" : "Uppdateringar",
    "App bundles" : "App-paket",
    "Featured apps" : "Utvalda appar",
    "Supported apps" : "Appar som stöds",
    "Show to everyone" : "Visa för alla",
    "Show to logged in accounts only" : "Visa endast till inloggade konton",
    "Hide" : "Dölj",
    "Download and enable" : "Hämta och aktivera",
    "Disable" : "Inaktivera",
    "Allow untested app" : "Tillåt otestad app",
    "The app will be downloaded from the App Store" : "Appen kommer hämtas från appbutiken",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Den här appen är inte markerad som kompatibel med din Nextcloud-version. Om du fortsätter kan du fortfarande installera appen. Observera att appen kanske inte fungerar som förväntat.",
    "Unknown" : "Okänd",
    "Never" : "Aldrig",
    "Could not register device: Network error" : "Kunde inte registrera enheten: Nätverksfel",
    "Could not register device: Probably already registered" : "Kunde inte registrera enheten: Förmodligen redan registrerad",
    "Could not register device" : "Det gick inte att registrera enheten",
    "An error occurred during the request. Unable to proceed." : "Ett fel uppstod under begäran. Det gick inte att fortsätta.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Fel: Denna appen kan inte aktiveras eftersom den gör servern instabil",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Appen har aktiverats men måste uppdateras. Du kommer att omdirigeras till uppdateringssidan om 5 sekunder.",
    "Do you really want to wipe your data from this device?" : "Vill du verkligen radera din data från den här enheten?",
    "Confirm wipe" : "Bekräfta radering",
    "Could not delete the app token" : "Det gick inte att ta bort apptoken",
    "Error while wiping the device with the token" : "Fel uppstod vid rensning av enheten",
    "Error while updating device token name" : "Fel vid uppdatering av enhetstokens namn",
    "Error while updating device token scope" : "Fel vid uppdatering av enhetstokens omfång",
    "Could not set group sorting" : "Kunde inte ställa in gruppsortering",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Det kom för många förfrågningar från ditt nätverk. Försök senare eller kontakta din administratör om detta är ett fel.",
    "Error" : "Fel",
    "Account documentation" : "Användardokumentation",
    "Administration documentation" : "Administratörsdokumentation",
    "Forum" : "Forum",
    "Nextcloud help & privacy resources" : "Nextcloud hjälp- och sekretessresurser",
    "General documentation" : "Dokumentationsöversikt",
    "Legal notice" : "Rättsligt meddelande",
    "Privacy policy" : "Integritetspolicy",
    "None/STARTTLS" : "Ingen/STARTTLS",
    "SSL" : "SSL",
    "Open documentation" : "Öppna dokumentation",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Det är viktigt att konfigurera den här servern för att kunna skicka e-post, till exempel för återställning av lösenord och aviseringar.",
    "Send mode" : "Sändningsläge",
    "Encryption" : "Kryptering",
    "Sendmail mode" : "Sendmail-läge",
    "From address" : "Från adress",
    "Server address" : "Serveradress",
    "Port" : "Port",
    "Authentication" : "Autentisering",
    "Authentication required" : "Autentisering krävs",
    "Credentials" : "Inloggningsuppgifter",
    "SMTP Login" : "SMTP-inloggning",
    "SMTP Password" : "SMTP-lösenord",
    "Save" : "Spara",
    "Test and verify email settings" : "Testa och verifiera e-postinställningar",
    "Security & setup warnings" : "Säkerhet & systemvarningar",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Det är viktigt för säkerhet och prestanda av din instans att allt är korrekt konfigurerat. För att hjälpa dig med det gör vi några automatiska kontroller. Se den länkade dokumentationen för mer information.",
    "All checks passed." : "Alla kontroller lyckades!",
    "There are some errors regarding your setup." : "Det finns några fel angående din inställning.",
    "There are some warnings regarding your setup." : "Det finns några varningar angående din inställning.",
    "Checking for system and security issues." : "Kontrollerar system och säkerhetsproblem.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Vänligen dubbelkolla <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installationsguiderna ↗</a>, och leta efter eventuella fel eller varningar i <a href=\"%2$s\">loggen</a>.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Kontrollera säkerheten av din Nextcloud-instans med <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">vår säkerhetsgenomsökning ↗</a>.",
    "Reasons to use Nextcloud in your organization" : "Anledningar att använda Nextcloud i din organisation",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Utvecklat av {communityopen}Nextcloud-gemenskapen{linkclose}, {githubopen}källkoden{linkclose}  är licensierad enligt {licenseopen}AGPL-standard{linkclose}.",
    "Like our Facebook page" : "Gilla vår Facebook-sida",
    "Follow us on X" : "Följ oss på X",
    "Follow us on Mastodon" : "Följ oss på Mastodon",
    "Check out our blog" : "Kolla in vår blogg",
    "Subscribe to our newsletter" : "Prenumerera på vårt nyhetsbrev",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Denna community-release av Nextcloud stöds inte och direktnotifikationer är inte tillgängliga.",
    "Use a second factor besides your password to increase security for your account." : "Använd en andra faktor utöver ditt lösenord för att öka säkerheten för ditt konto.",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Om du använder tredje-parts applikationer för att ansluta till Nextcloud vänligen skapa och konfigurera ett applösenord för varje innan två-faktor autentisering aktiveras.",
    "Logged in account must be a subadmin" : "Inloggat konto måste vara en underadministratör",
    "Missing optional index \"%s\" in table \"%s\"." : "Saknar valfri index \"%s\" i tabellen \"%s\".",
    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Databasen saknar några index. Dessa adderas inte automatsikt då indexering av stora tabeller kan ta tid. Med kommandot  \"occ db:add-missing-indices\" kan de saknade indices läggas till manuellt utan att instansen behöver stoppas. Indexerade tabeller ger oftast mycket snabbare svar.",
    "File locking" : "Fillåsning",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems." : "Transaktionsbaserad fillåsning är inaktiverad, detta kan leda till problem med konflikter. Aktivera \"filelocking.enabled\" i config.php för att undvika dessa problem.",
    "The PHP memory limit is below the recommended value of %s." : "Minnesgränsen för PHP är under det rekommenderade värdet på %s.",
    "You are currently running PHP %s. PHP 8.0 is now deprecated in Nextcloud 27. Nextcloud 28 may require at least PHP 8.1. Please upgrade to one of the officially supported PHP versions provided by the PHP Group as soon as possible." : "Du kör för närvarande PHP %s. PHP 8.0 är nu föråldrat i Nextcloud 27. Nextcloud 28 kan kräva minst PHP 8.1. Vänligen uppgradera till en av de officiellt stödda PHP-versionerna som tillhandahålls av PHP Group så snart som möjligt.",
    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "MariaDB version \"%s\" används. Nextcloud 21 och högre stöder inte denna version och kräver MariaDB 10.2 eller högre.",
    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "MySQL-versionen \"%s\" används. Nextcloud 21 och högre stöder inte denna version och kräver MySQL 8.0 eller MariaDB 10.2 eller högre.",
    "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "PostgreSQL-versionen \"%s\" används. Nextcloud 21 och högre stöder inte denna version och kräver PostgreSQL 9.6 eller högre.",
    "Speech-To-Text" : "Tal-till-text",
    "Speech-To-Text can be implemented by different apps. Here you can set which app should be used." : "Tal-till-text kan implementeras av olika appar. Här kan du ställa in vilken app som ska användas.",
    "None of your currently installed apps provide Speech-To-Text functionality" : "Ingen av dina installerade appar tillhandahåller tal-till-text-funktionalitet",
    "None of your currently installed apps provide Text processing functionality" : "Ingen av dina installerade appar tillhandahåller textbearbetningsfunktioner",
    "Set default expiration date for shares" : "Ställ in standardutgångsdatum för delningar",
    "Allow username autocompletion in share dialog and allow access to the system address book" : "Tillåt autokomplettering av användarnamn i delningsdialogen och tillåt åtkomst till systemets adressbok",
    "Your biography" : "Din biografi",
    "You are using <strong>{usage}</strong>" : "Du använder <strong>{usage}</strong>",
    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Du använder <strong>{usage}</strong> av <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
    "Set user manager" : "Ställ in användarhanterare",
    "Username will be autogenerated" : "Användarnamn kommer att autogenereras",
    "Username (required)" : "Användarnamn (obligatoriskt)",
    "New user" : "Ny användare",
    "Groups (required)" : "Grupper (obligatoriskt)",
    "Set user groups" : "Ställ in användargrupper",
    "Administered groups" : "Administrerade grupper",
    "Set user as admin for …" : "Ange användare som administratör för...",
    "Set user quota" : "Ställ in användarkvot",
    "Add new user" : "Lägg till ny användare",
    "_{userCount} user …_::_{userCount} users …_" : ["{userCount} användare …","{userCount} användare …"],
    "_{userCount} user_::_{userCount} users_" : ["{userCount} användare","{userCount} användare"],
    "Loading users …" : "Laddar användare …",
    "Username" : "Användarnamn",
    "User backend" : "Användarbackend",
    "User actions" : "Användaråtgärder",
    "Add user to group" : "Lägg till användare i grupp",
    "Server error while trying to add WebAuthn device" : "Serverfel när du försökte lägga till en WebAuthn-enhet",
    "Name your device" : "Namnge din enhet",
    "Active accounts" : "Aktiva konton",
    "Follow us on Twitter" : "Följ oss på Twitter",
    "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "För att denna kontroll ska kunna köra måste du se till att webbservern kan ansluta till sig själv. Den måste alltså kunna finna och ansluta till minst en av sina \"trusted_domains\" eller \"overwrite.cli.url\":en. Detta misslyckande kan vara resultatet av en DNS missmatch på serversidan eller utgående brandväggs-regler."
},
"nplurals=2; plural=(n != 1);");
